@@ -28,7 +28,6 @@ OC.L10N.register(
     "No file provided for import" : "Κανένα αρχείο για εισαγωγή",
     "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
     "Bookmarks shared by %s" : "Σελιδοδείκτες σε κοινή χρήση από %s",
-    "Recent Bookmarks" : "Πρόσφατοι Σελιδοδείκτες",
     "Bookmark" : "Σελιδοδείκτης",
     "Bookmark deleted" : "Ο σελιδοδείκτης διαγράφηκε",
     "Bookmark created" : "Ο σελιδοδείκτης δημιουργήθηκε",
@@ -44,22 +43,20 @@ OC.L10N.register(
     "Move" : "Μετακίνηση",
     "Delete" : "Διαγραφή",
     "Do you really want to delete this bookmark?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον σελιδοδείκτη;",
-    "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
-    "New" : "Νέα",
-    "New bookmark" : "Νέος σελιδοδείκτης",
-    "New folder" : "Νέος φάκελος",
-    "Grid view" : "Προβολή πλέγματος",
-    "List view" : "Προβολή λίστας",
-    "RSS Feed of current view" : "RSS Feed της τρέχουσας προβολής",
+    "Open all selected" : "Άνοιγμα των επιλεγμένων",
     "Move selection" : "Μετακίνηση επιλογής",
     "Delete selection" : "Διαγραφή επιλογής",
-    "Open all selected" : "Άνοιγμα των επιλεγμένων",
     "Select all" : "Επιλογή όλων",
     "Cancel selection" : "Ακύρωση επιλογής",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Επιλεγμένοι {folders} φάκελοι και {bookmarks} σελιδοδείκτες",
     "Do you really want to delete these items?" : "Θέλετε πραγματικά να διαγράψετε αυτά τα στοιχεία;",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
     "_Selected %n folder_::_Selected %n folders_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
+    "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
+    "New" : "Νέα",
+    "New bookmark" : "Νέος σελιδοδείκτης",
+    "New folder" : "Νέος φάκελος",
+    "RSS feed copied" : "Η ροή πληροφοριών RSS αντιγράφηκε",
     "Enter a link" : "Εισάγετε σύνδεσμο",
     "Enter a title" : "Εισάγετε ένα τίτλο",
     "No bookmarks found" : "Δεν βρέθηκαν σελιδοδείκτες",
@@ -67,7 +64,6 @@ OC.L10N.register(
     "Enter folder title" : "Τίτλος φακέλου",
     "Shared by {user}" : "Διαμοιράστηκε από {user}",
     "Do you really want to delete this folder?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον φάκελο;",
-    "Root folder" : "Αρχικός φάκελος",
     "Submit" : "Υποβολή",
     "Cancel" : "Ακύρωση",
     "Deleting bookmarks" : "Γίνεται διαγραφή σελιδοδεικτών",
@@ -79,25 +75,15 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Μετακίνηση %n σελιδοδείκτη","Μετακίνηση %n σελιδοδεικτών"],
     "All bookmarks" : "Όλοι οι σελιδοδείκτες",
     "Recent" : "Πρόσφατα",
-    "Archived" : "Αρχειοθετήθηκε",
     "Broken links" : "Κατεστραμμένοι σύνδεσμοι",
-    "Filter tags" : "Φίλτρο ετικετών",
     "Untagged" : "Χωρίς ετικέτα",
     "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
-    "No archived bookmarks" : "Κανένας αρχειοθετημένος σελιδοδείκτης",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Οι σελιδοδείκτες σε αρχεία όπως φωτογραφίες ή PDF θα αποθηκευτούν αυτόματα στα αρχεία Nextcloud, ώστε να μπορείτε να τα βρείτε ακόμα και όταν ο σύνδεσμος είναι εκτός σύνδεσης.",
     "No bookmarks here" : "Δεν υπάρχουν σελιδοδείκτες εδώ",
-    "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
     "Import bookmarks" : "Εισαγωγή σελιδοδεικτών",
     "Sync with your browser" : "Συγχρονισμός με τον περιηγητή σας",
     "Import" : "Εισαγωγή",
     "Export" : "Εξαγωγή",
-    "Sorting" : "Ταξινόμηση",
-    "Recently added" : "Προστέθηκαν πρόσφατα",
-    "Alphabetically" : "Αλφαβητικά",
-    "Most visited" : "Πιο δημοφιλή",
-    "Last modified" : "Τελευταία τροποίηση",
-    "Custom order" : "Προσαρμοσμένη εντολή",
     "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
     "Enter the path of a folder where bookmarked files should be stored" : "Προσθέστε την διαδρομή του φακέλου όπου θα αποθηκεύονται τα αρχεία σελιδοδεικτών",
     "Client apps" : "Εφαρμογές πελάτη",
@@ -114,15 +100,10 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "Παρακαλούμε επιλέξτε «Προσθήκη στην αρχική οθόνη» από το μενού του περιηγητή",
     "Title" : "Τίτλος",
     "Link" : "Σύνδεσμος",
-    "Creation date" : "Ημερομηνία δημιουργίας",
     "Tags" : "Ετικέτες",
     "Select tags and create new ones" : "Επιλέξτε ετικέτες και δημιουργήστε νέες",
-    "Attachments" : "Συνημμένα",
-    "Archived version" : "Αρχειοθετημένη έκδοση",
-    "Open archived file" : "Άνοιγμα αρχειοθετημένου αρχείου",
     "Notes" : "Σημειώσεις",
     "Notes for this bookmark …" : "Σημειώσεις για αυτό το σελιδοδείκτη …",
-    "{time} ago" : "{time} πριν",
     "Owner" : "Κάτοχος",
     "Sharing" : "Διαμοιρασμός",
     "Select a user or group" : "Επιλογή χρήστη ή ομάδας",
@@ -132,11 +113,14 @@ OC.L10N.register(
     "Delete link" : "Διαγραφή συνδέσμου",
     "Create public link" : "Δημιουργία δημόσιου συνδέσμου",
     "Allow editing" : "Επιτρέπεται η επεξεργασία",
-    "Allow sharing" : "Να επιτρέπεται ο διαμοιρασμός",
     "Remove share" : "Κατάργηση διαμοιρασμού",
     "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
-    "RSS feed copied" : "Η ροή πληροφοριών RSS αντιγράφηκε",
-    "Select" : "Επιλογή",
+    "Privacy" : "Ιδιωτικότητα",
+    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Οι σελιδοδείκτες θα προσπαθήσουν να έχουν πρόσβαση στις ιστοσελίδες που προσθέτετε για την αυτόματη πληροφόρησή σας.",
+    "Enable accessing and collecting information from the web pages you add" : "Ενεργοποιήστε την πρόσβαση και συλλογή πληροφοριών των ιστοσελίδων που προσθέτετε",
+    "Performance" : "Απόδοση",
+    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Σε μια εγκατάσταση με πολλούς χρήστες μπορεί να είναι χρήσιμο να περιοριστεί ο αριθμός των σελιδοδεικτών ανά λογαριασμό.",
+    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Μέγιστος επιτρεπόμενος αριθμός σελιδοδεικτών ανά λογαριασμό. (0 χωρίς όριο; η προεπιλογή δεν έχει όριο)",
     "Previews" : "Προεπισκοπήσεις",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Προκειμένου να προβάλλονται τα πραγματικά στιγμιότυπα οθόνης των ιστοσελίδων που προσθέτετε στους σελιδοδείκτες, η εφαρμογή Bookmarks μπορεί να χρησιμοποιήσει μια υπηρεσία τρίτου μέρους, για τη δημιουργία προεπισκόπησης.",
     "Screeenly" : "Screeenly",
@@ -149,14 +133,9 @@ OC.L10N.register(
     "ScreenshotMachine API key" : "ScreenshotMachine API key",
     "Pageres CLI" : "Pageres CLI",
     "Simply install the pageres cli on your server and bookmarks will find it." : "Απλά εγκαταστήστε το pageres cli στο διακομιστή σας και οι σελιδοδείκτες θα το βρουν.",
-    "Privacy" : "Ιδιωτικότητα",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Οι σελιδοδείκτες θα προσπαθήσουν να έχουν πρόσβαση στις ιστοσελίδες που προσθέτετε για την αυτόματη πληροφόρησή σας.",
-    "Enable accessing and collecting information from the web pages you add" : "Ενεργοποιήστε την πρόσβαση και συλλογή πληροφοριών των ιστοσελίδων που προσθέτετε",
-    "Performance" : "Απόδοση",
-    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Σε μια εγκατάσταση με πολλούς χρήστες μπορεί να είναι χρήσιμο να περιοριστεί ο αριθμός των σελιδοδεικτών ανά λογαριασμό.",
-    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Μέγιστος επιτρεπόμενος αριθμός σελιδοδεικτών ανά λογαριασμό. (0 χωρίς όριο; η προεπιλογή δεν έχει όριο)",
     "Failed to load settings" : "Αποτυχία φόρτωσης ρυθμίσεων",
     "Failed to save settings" : "Αποτυχία αποθήκευσης ρυθμίσεων",
+    "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
     "This URL is already bookmarked! Overwrite?" : "Υπάρχει ήδη σελιδοδείκτης με αυτή τη διεύθυνση URL! Αντικατάσταση;",
     "Enter bookmark title" : "Καταχωρίστε έναν τίτλο σελιδοδείκτη",
     "Enter bookmark URL" : "Καταχωρίστε τη διεύθυνση URL σελιδοδείκτη",
