@@ -24,7 +24,6 @@ OC.L10N.register(
     "No file provided for import" : "Tuotavaa tiedostoa ei ole valittu",
     "Unsupported file type for import" : "Tiedoston tyyppi ei ole tuotavaa muotoa",
     "Bookmarks shared by %s" : "Henkilön %s jakamat kirjanmerkit",
-    "Recent Bookmarks" : "Uusimmat kirjanmerkit",
     "Bookmark" : "Kirjanmerkki",
     "Bookmark deleted" : "Kirjanmerkki poistettu",
     "Bookmark created" : "Kirjanmerkki luotu",
@@ -37,25 +36,23 @@ OC.L10N.register(
     "Rename" : "Nimeä uudelleen",
     "Move" : "Siirrä",
     "Delete" : "Poista",
-    "Select one or more tags" : "Valitse yksi tai useampi tunniste",
-    "New" : "Uusi",
-    "New bookmark" : "Uusi kirjanmerkki",
-    "New folder" : "Uusi kansio",
-    "Grid view" : "Ruudukkonäkymä",
-    "List view" : "Luettelonäkymä",
+    "Open all selected" : "Avaa kaikki valitut",
     "Move selection" : "Siirrä valintaa",
     "Delete selection" : "Poista valinta",
-    "Open all selected" : "Avaa kaikki valitut",
     "Select all" : "Valitse kaikki",
     "Cancel selection" : "Peruuta valinta",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valittu {folders} kansiota ja {bookmarks} kirjanmerkkiä",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valittu %n kirjanmerkki","Valittu %n kirjanmerkkiä"],
     "_Selected %n folder_::_Selected %n folders_" : ["Valittu %n kansio","Valittu %n kansiota"],
+    "Select one or more tags" : "Valitse yksi tai useampi tunniste",
+    "New" : "Uusi",
+    "New bookmark" : "Uusi kirjanmerkki",
+    "New folder" : "Uusi kansio",
+    "RSS feed copied" : "RSS-syöte kopioitu",
     "Enter a link" : "Anna linkki",
     "Select folder" : "Valitse kansio",
     "Enter folder title" : "Anna nimi kansiolle",
     "Shared by {user}" : "Jakanut {user}",
-    "Root folder" : "Juurikansio",
     "Submit" : "Lähetä",
     "Cancel" : "Peruuta",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Siirretään %n kansio ja joitain kirjanmerkkejä","Siirretään %n kansiota ja joitain kirjanmerkkejä"],
@@ -63,23 +60,13 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Siirretään %n kirjanmerkki","Siirretään %n kirjanmerkkiä"],
     "All bookmarks" : "Kaikki kirjanmerkit",
     "Recent" : "Viimeisimmät",
-    "Archived" : "Arkistoitu",
     "Broken links" : "Rikkinäisiä linkkejä",
-    "Filter tags" : "Suodata tunnisteita",
     "Untagged" : "Ilman tunnistetta",
     "{used} bookmarks of {available} available" : "{used}/{available} kirjanmerkkiä käytettävissä",
-    "No archived bookmarks" : "Ei arkistoituja kirjanmerkkejä",
     "No bookmarks here" : "Ei kirjanmerkkejä täällä",
-    "Add a bookmark" : "Lisää kirjanmerkki",
     "Import bookmarks" : "Tuo kirjanmerkit",
     "Import" : "Tuo",
     "Export" : "Vie",
-    "Sorting" : "Lajittelu",
-    "Recently added" : "Äskettäin lisätty",
-    "Alphabetically" : "Aakkosjärjestys",
-    "Most visited" : "Vierailuimmat",
-    "Last modified" : "Viimeksi muokattu",
-    "Custom order" : "Mukautettu järjestys",
     "Bookmarklet" : "Sovelluskirjanmerkki",
     "Clear data" : "Tyhjennä tiedot",
     "Permanently remove all bookmarks from your account." : "Poista kaikki tililläsi olevat kirjanmerkit pysyvästi.",
@@ -87,15 +74,10 @@ OC.L10N.register(
     "Do you really want to delete all your bookmarks?" : "Haluatko varmasti poistaa kaikki kirjanmerkkisi?",
     "Title" : "Otsikko",
     "Link" : "Linkki",
-    "Creation date" : "Luontipäivä",
     "Tags" : "Tunnisteet",
     "Select tags and create new ones" : "Valitse tunnisteet tai luo uusia",
-    "Attachments" : "Liitteet",
-    "Archived version" : "Arkistoitu versio",
-    "Open archived file" : "Avaa arkistoitu tiedosto",
     "Notes" : "Muistiinpanot",
     "Notes for this bookmark …" : "Muistiinpanot tähän kirjanmerkkiin liittyen…",
-    "{time} ago" : "{time} sitten",
     "Owner" : "Omistaja",
     "Sharing" : "Jakaminen",
     "Select a user or group" : "Valitse käyttäjä tai ryhmä",
@@ -105,11 +87,12 @@ OC.L10N.register(
     "Delete link" : "Poista linkki",
     "Create public link" : "Luo julkinen linkki",
     "Allow editing" : "Salli muokkaus",
-    "Allow sharing" : "Salli jakaminen",
     "Remove share" : "Poista jako",
     "Link copied" : "Linkki kopioitu",
-    "RSS feed copied" : "RSS-syöte kopioitu",
-    "Select" : "Valitse",
+    "Privacy" : "Yksityisyys",
+    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Kirjanmerkkisovellus pyrkii niille sivuille, jotka lisäät kirjanmerkkeihin, jotta sivuista voidaan noutaa automaattisesti lisätietoja.",
+    "Performance" : "Suorituskyky",
+    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Käyttäjätilikohtaisten kirjanmerkkien enimmäismäärä. (0 tarkoittaa ei rajoitusta; oletus on ei rajoitusta)",
     "Previews" : "Esikatselut",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Voit rekisteröityä veloituksetta osoitteessa screeenly.com tai pystyttää oman palvelimen.",
@@ -119,12 +102,9 @@ OC.L10N.register(
     "Webshot API URL" : "Webshotin API:n URL",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachinen API-avain",
-    "Privacy" : "Yksityisyys",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Kirjanmerkkisovellus pyrkii niille sivuille, jotka lisäät kirjanmerkkeihin, jotta sivuista voidaan noutaa automaattisesti lisätietoja.",
-    "Performance" : "Suorituskyky",
-    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Käyttäjätilikohtaisten kirjanmerkkien enimmäismäärä. (0 tarkoittaa ei rajoitusta; oletus on ei rajoitusta)",
     "Failed to load settings" : "Asetusten lataaminen epäonnistui",
     "Failed to save settings" : "Asetusten tallentaminen epäonnistui",
+    "Add a bookmark" : "Lisää kirjanmerkki",
     "This URL is already bookmarked! Overwrite?" : "Osoite on jo lisätty kirjanmerkkeihin. Korvataanko se?",
     "Enter bookmark title" : "Anna nimi kirjanmerkille",
     "Enter bookmark URL" : "Kirjoita kirjanmerkin osoite",
